@@ -7,7 +7,7 @@ from openai.types.chat.chat_completion_message_param import ChatCompletionMessag
 
 from mtmai.mtlibs.aiutils import lcllm_openai_chat
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 # @tool
