@@ -9,7 +9,7 @@ from mtmai.teams.graph_state import State
 from mtmai.teams.tools_node import tools_node
 from mtmai.teams.weather_node import weather_node
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 def should_continue(state: State) -> Literal["__end__", "tools", "continue"]:
