@@ -5,11 +5,11 @@ from sqlmodel import Session, select
 
 from mtmai.core.config import settings
 from mtmai.core.db import getdb
-from mtmai.models import ChatMessage
+from mtmai.models.chat import ChatMessage
 
 router = fastapi.APIRouter()
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 def register_api_router(app: fastapi.FastAPI):
