@@ -5,7 +5,7 @@ from pydantic import BaseModel
 
 from mtmai.core.config import settings
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 router = APIRouter()
 
