@@ -4,6 +4,6 @@ from fastapi.responses import RedirectResponse
 router = APIRouter()
 
 
-@router.get("/")
+@router.get("/", include_in_schema=False)
 def home():
     return RedirectResponse("/docs")
