@@ -7,13 +7,13 @@ from opentelemetry import trace
 from mtmai.core.config import settings
 
 tracer = trace.get_tracer_provider().get_tracer(__name__)
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 router = APIRouter()
 
 
-@router.get("/health")
+@router.get("/health", include_in_schema=False)
 async def health_check():
     with tracer.start_as_current_span("health-span"):
         logger.info("get /health")
