@@ -1,10 +1,7 @@
 import threading
 
 from fastapi import APIRouter
-
-from mtmai.core.config import settings
-from mtmai.core.coreutils import is_in_vercel
-from mtmai.mtlibs.process_helper import bash
+from mtmlib.mtutils import bash
 
 router = APIRouter()
 
@@ -28,10 +25,6 @@ def run_searxng_server():
     )
 
 
-if not is_in_vercel() and not settings.is_in_gitpod:
-    threading.Thread(target=run_searxng_server).start()
-
-
 @router.get("/serve")
 def start_searxng():
     threading.Thread(target=run_searxng_server).start()
