@@ -4,7 +4,7 @@ from pydantic import BaseModel
 from pydantic.networks import EmailStr
 
 from mtmai.api.deps import get_current_active_superuser
-from mtmai.models import Message
+from mtmai.models.models import Message
 from mtmai.utils import generate_test_email, send_email
 
 router = APIRouter()
@@ -14,6 +14,7 @@ router = APIRouter()
     "/test-email/",
     dependencies=[Depends(get_current_active_superuser)],
     status_code=201,
+    include_in_schema=False,
 )
 def test_email(email_to: EmailStr) -> Message:
     """
@@ -36,6 +37,7 @@ class TestUrlReq(BaseModel):
     "/test-url/",
     dependencies=[Depends(get_current_active_superuser)],
     status_code=201,
+    include_in_schema=False,
 )
 async def test_url(req: TestUrlReq):
     client = httpx.AsyncClient()
