@@ -4,14 +4,11 @@ import time
 from pathlib import Path
 
 from fastapi import APIRouter
+from mtmlib.mtutils import bash
 from opentelemetry import trace
 
-from mtmai.core import coreutils
-from mtmai.core.config import settings
-from mtmai.mtlibs.process_helper import bash
-
 tracer = trace.get_tracer_provider().get_tracer(__name__)
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 router = APIRouter()
@@ -19,7 +16,6 @@ router = APIRouter()
 
 # 官网： https://coder.com/docs/install
 def start_code_server():
-
     config_file = Path.home().joinpath(".config/code-server/config.yaml")
     if not config_file.exists():
         logger.warning("code-server 配置文件不存在, 跳过启动: %s", config_file)
@@ -34,14 +30,6 @@ def start_code_server():
     logger.info("codeserver 配置: %s", config_content)
 
 
-if (
-    not settings.is_in_vercel
-    and not settings.is_in_gitpod
-    and not coreutils.is_in_windows()
-):
-    threading.Thread(target=start_code_server).start()
-
-
-@router.get("/start")
+@router.get("/start", include_in_schema=False)
 async def start():
     threading.Thread(target=start_code_server).start()
