@@ -3,15 +3,14 @@ import threading
 from pathlib import Path
 
 from fastapi import APIRouter
+from mtmlib.httpUtils import download_file
+from mtmlib.mtutils import bash
 
-from mtmai.core import coreutils
 from mtmai.core.config import settings
-from mtmai.mtlibs.httpUtils import download_file
 from mtmai.mtlibs.mtutils import command_exists
-from mtmai.mtlibs.process_helper import bash
 
 router = APIRouter()
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 def start_cloudflared():
@@ -26,22 +25,12 @@ def start_cloudflared():
     )
 
 
-if (
-    not settings.is_in_vercel
-    and not settings.is_in_gitpod
-    and settings.CF_TUNNEL_TOKEN
-    and not coreutils.is_in_huggingface()
-    and not coreutils.is_in_windows()
-):
-    start_cloudflared()
-
-
-@router.get("/start")
+@router.get("/start", include_in_schema=False)
 def start():
     threading.Thread(target=start_cloudflared).start()
 
 
-@router.get("/install")
+@router.get("/install", include_in_schema=False)
 def install():
     if not command_exists("cloudflared"):
         logger.info("cloudflared 命令不存在现在安装")
