@@ -9,13 +9,13 @@ from mtmai.api.deps import SessionDep
 from mtmai.worker import worker
 
 tracer = trace.get_tracer_provider().get_tracer(__name__)
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 router = APIRouter()
 
 
-@router.get("/start_worker")
+@router.get("/start_worker", include_in_schema=False)
 async def start_worker(
     session: SessionDep,
 ):
