@@ -5,7 +5,7 @@ from sqlmodel import Session
 from mtmai.core.db import engine, init_db
 
 logging.basicConfig(level=logging.INFO)
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 def init() -> None:
