@@ -5,7 +5,7 @@ from langchain_core.messages import ToolMessage
 
 from .graph_state import State, create_response
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 def human_node(state: State):
