@@ -18,12 +18,12 @@ from pydantic import BaseModel, Field
 from typing_extensions import TypedDict
 
 from mtmai.llm.llm import get_fast_llm, get_long_context_llm
-from mtmai.models import ChatMessage
+from mtmai.models.chat import ChatMessage
 from mtmai.mtlibs import mtutils
 from mtmai.mtlibs.aiutils import flow_events
 
 router = APIRouter()
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 def register_api_router(app: fastapi.FastAPI):
