@@ -2,13 +2,13 @@ import logging
 import pprint
 from typing import Literal
 
+from langchain_core.tools import tool
 from langgraph.graph import MessagesState
 
 from mtmai.mtlibs.aiutils import lcllm_openai_chat
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
-from langchain_core.tools import tool
 
 
 @tool
