@@ -1,7 +1,7 @@
 from sqlmodel import Session
 
-from mtmai import crud
-from mtmai.models import Item, ItemCreate
+from mtmai.curd import crud
+from mtmai.models.models import Item, ItemCreate
 from mtmai.tests.utils.user import create_random_user
 from mtmai.tests.utils.utils import random_lower_string
 
