@@ -7,7 +7,7 @@ from tenacity import after_log, before_log, retry, stop_after_attempt, wait_fixe
 from mtmai.core.db import engine
 
 logging.basicConfig(level=logging.INFO)
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 max_tries = 60 * 5  # 5 minutes
 wait_seconds = 1
@@ -20,12 +20,13 @@ wait_seconds = 1
     after=after_log(logger, logging.WARNING),
 )
 def init(db_engine: Engine) -> None:
+    logger.info("检测数据库是否在线")
     try:
         # Try to create session to check if DB is awake
         with Session(db_engine) as session:
             session.exec(select(1))
     except Exception as e:
-        logger.error(e)
+        logger.exception(f"数据库连接似乎出错 {e}")  # noqa: G004
         raise e
 
 
